@@ -35,7 +35,7 @@ from .utils import MISSING
 
 if TYPE_CHECKING:
     from .user import ClientUser
-    from .embeds import Ark, Embed
+    from .embeds import Ark, Embed, Markdown
     from .member import Member
     from .channel import CategoryChannel, TextChannel, PartialMessageable, DMChannel
     from .guild import Guild
@@ -113,6 +113,7 @@ class Messageable:
             mention_author: Member = ...,
             ark: Ark = ...,
             embed: Embed = ...,
+            markdown: Markdown = ...,
             file: File = ...,
             delete_after: float = ...,
     ) -> Union[Message, str]:
@@ -128,8 +129,10 @@ class Messageable:
             mention_author=None,
             ark=None,
             embed=None,
+            markdown=None,
             file=None,
             delete_after=None,
+            replace_url=True,
     ):
         """|coro|
         使用给定的内容向目的地发送消息。
@@ -147,6 +150,8 @@ class Messageable:
             要发送的 Ark 类
         embed: Optional[:class:`qq.Embed`]
             要发送的 Embed 类
+        markdown: Optional[:class:`qq.Markdown`]
+            要发送的 Markdown 类
         msg_id: Union[:class:`~qq.Message`, :class:`~qq.MessageReference`, :class:`~qq.PartialMessage`]
             被动消息使用的消息
 
@@ -166,6 +171,8 @@ class Messageable:
             本地上传的图片文件。
         delete_after: Optional[:class:`float`]
             如果设置了，则等待该秒数之后自动撤回消息。如果删除失败，则它会被静默忽略。
+        replace_url: Optional[:class:`bool`]
+            是否添加转义字符来绕过腾讯的链接检测。默认为 ``True`` 。
 
         Raises
         --------
@@ -201,18 +208,19 @@ class Messageable:
             try:
                 reference = reference.to_message_reference_dict()
             except AttributeError:
-                raise InvalidArgument(
-                    'reference 参数必须是 Message、 MessageReference 或 PartialMessage') from None
+                raise InvalidArgument('reference 参数必须是 Message、 MessageReference 或 PartialMessage') from None
 
         with handle_message_parameters(
-            content=content,
-            direct=direct,
-            msg_id=msg_id,
-            file=file if file is not None else MISSING,
-            image=image if image is not None else MISSING,
-            embed=embed if embed is not None else MISSING,
-            ark=ark if ark is not None else MISSING,
-            message_reference=reference if reference is not None else MISSING,
+                content=content,
+                direct=direct,
+                msg_id=msg_id,
+                file=file if file is not None else MISSING,
+                image=image if image is not None else MISSING,
+                embed=embed if embed is not None else MISSING,
+                ark=ark if ark is not None else MISSING,
+                markdown=markdown if markdown is not None else MISSING,
+                message_reference=reference if reference is not None else MISSING,
+                replace_url=replace_url,
         ) as params:
             data = await state.http.send_message(channel.id, params=params)
 
