@@ -26,7 +26,8 @@ from typing import Any, Dict, Final, List, Mapping, Protocol, TYPE_CHECKING, Typ
 
 __all__ = (
     'Embed',
-    'Ark'
+    'Ark',
+    'Markdown'
 )
 
 from . import utils
@@ -63,9 +64,10 @@ class EmbedProxy:
 
 
 E = TypeVar('E', bound='Embed')
+MD = TypeVar('MD', bound='Markdown')
 
 if TYPE_CHECKING:
-    from .types.embed import Embed as EmbedData
+    from .types.embed import Embed as EmbedData, MarkdownData
 
     T = TypeVar('T')
     MaybeEmpty = Union[T, _EmptyEmbed]
@@ -107,6 +109,102 @@ if TYPE_CHECKING:
         proxy_icon_url: MaybeEmpty[str]
 
 
+class Markdown:
+    """代表一个 QQ Markdown。
+
+    .. container:: operations
+
+        .. describe:: bool(b)
+
+            返回 Markdown 是否有任何数据集。
+
+    Attributes
+    -----------
+    template_id: :class:`int`
+        要使用的模版 ID。
+    custom_template_id: :class:`str`
+        要使用的自定义模版 ID。
+    content: :class:`str`
+        原生 markdown 内容，如果设置了此项，将忽略 template_id 和 custom_template_id。
+    """
+    __slots__ = (
+        '_fields',
+        'custom_template_id',
+        'template_id',
+        'content',
+    )
+
+    def __init__(
+            self,
+            *,
+            template_id: int = None,
+            custom_template_id: str = None,
+            content: str = None,
+    ):
+        self._fields = {}
+        self.template_id = template_id
+        self.content = content
+        self.custom_template_id = custom_template_id
+        if not self:
+            raise ValueError('Markdown must have at least one field.')
+
+    @property
+    def fields(self) -> Dict[str, Any]:
+        return self._fields
+
+    def set_attribute(self: MD, key: Any, value: Any) -> MD:
+        """向 Markdown 对象添加字段。此函数返回类实例以允许流式链接。
+
+        Parameters
+        -----------
+        key: :class:`str`
+            字段的名称。
+        value: :class:`str`
+            字段的值。
+        """
+
+        self._fields[str(key)] = str(value)
+        return self
+
+    def clear_fields(self) -> None:
+        """从此 Markdown 中删除所有字段。"""
+        try:
+            self._fields.clear()
+        except AttributeError:
+            self._fields = {}
+
+    def to_dict(self) -> MarkdownData:
+        """将此 Markdown 对象转换为字典。"""
+
+        if not self.content:
+            result = {"template_id": self.template_id, "custom_template_id": self.custom_template_id}
+
+            if self._fields:
+                result["params"] = [{"key": k, "values": v} for k, v in self._fields.items()]
+        else:
+            result = {"content": self.content}
+
+        return result  # type: ignore
+
+    @classmethod
+    def from_dict(cls, template_id: int, data: Optional[Dict[str, List[str]]] = None) -> MD:
+        """从字典创建一个 Markdown 对象。"""
+        if data is None:
+            data = {}
+        self = cls(template_id=template_id)
+        self._fields = {k: v for k, v in data.items()}
+        return self
+
+    def __bool__(self):
+        return any(
+            (
+                self.template_id is not None,
+                self.content is not None,
+                self.custom_template_id is not None,
+            )
+        )
+
+
 class Ark:
     """代表一个 QQ Ark。
 
@@ -326,10 +424,9 @@ class Embed:
     @classmethod
     def from_dict(cls: Type[E], data: Mapping[str, Any]) -> E:
         """将 :class:`dict` 转换为 :class:`Embed`，前提是它采用 QQ 期望的格式。
-        你可以在 ``官方 QQ 文档``__ 中找到有关此格式的信息。
+        你可以在 ``官方 QQ 文档`` 中找到有关此格式的信息。
 
-        .. _QQDocs: https://bot.q.qq.com/wiki/develop/api/openapi/message/model.html#messageembed
-        __ QQDocs_
+        https://bot.q.qq.com/wiki/develop/api/openapi/message/model.html#messageembed
 
         Parameters
         -----------
