@@ -36,7 +36,7 @@ from urllib.parse import quote as _uriquote
 import aiohttp
 
 from . import __version__, utils
-from .embeds import Ark, Embed
+from .embeds import Ark, Embed, Markdown
 from .error import HTTPException, Forbidden, NotFound, QQServerError, LoginFailure, GatewayNotFound
 from .gateway import QQClientWebSocketResponse
 from .types import user, guild, message, channel, member
@@ -127,7 +127,9 @@ def handle_message_parameters(
         image: Optional[str] = MISSING,
         embed: Optional[Embed] = MISSING,
         ark: Optional[Ark] = MISSING,
+        markdown: Optional[Markdown] = MISSING,
         message_reference: Optional[MessageReference] = MISSING,
+        replace_url: bool = True,
 ) -> MultipartParameters:
     payload = {}
     if msg_id:
@@ -137,7 +139,10 @@ def handle_message_parameters(
         payload['embed'] = embed.to_dict()
 
     if ark:
-        payload['ark'] = ark
+        payload['ark'] = ark.to_dict()
+
+    if markdown:
+        payload['markdown'] = markdown.to_dict()
 
     if image:
         payload['image'] = image
@@ -148,8 +153,8 @@ def handle_message_parameters(
         else:
             pass
 
-    if content:
-        payload['content'] = content.replace(".", "\ufeff.")
+    if replace_url:
+        payload['content'] = payload['content'].replace(".", "\ufeff.")
 
     if message_reference is not MISSING:
         payload['message_reference'] = message_reference
@@ -278,8 +283,11 @@ class HTTPClient:
                     kwargs['data'] = form_data
                 try:
                     async with self.__session.request(method, url, **kwargs) as response:
-                        _log.debug('%s %s 与 %s 已返回 %s Trace ID: %s', method, url, kwargs.get('data'),
-                                   response.status, response.headers['X-Tps-trace-ID'])
+                        _log.debug(
+                            '%s %s 与 %s 已返回 %s Trace ID: %s', method, url, kwargs.get('data'),
+                            response.status,
+                            response.headers['X-Tps-trace-ID'] if 'X-Tps-trace-ID' in response.headers else "Missing"
+                        )
 
                         # even errors have text involved in them so this is safe to call
                         data = await json_or_text(response)
